@@ -25,6 +25,8 @@
 #include "servermanager_p.h"
 
 #include <klocale.h>
+#include <klocalizedstring.h>
+#include <kglobal.h>
 
 #include <QtCore/QThread>
 #include <QtCore/QThreadStorage>
