@@ -24,6 +24,7 @@
 #include "incidencechanger.h"
 
 #include <QVector>
+#include <QMultiHash>
 
 class KJob;
 
@@ -42,7 +43,10 @@ public:
 
   void deleteAllIncidencesOfType( const QString &mimeType );
 
-  void handleUidChange( const Akonadi::Item &newItem, const QString &newUid );
+  void handleUidChange( const Akonadi::Item &oldItem, const Akonadi::Item &newItem, const QString &newUid );
+
+  // Checks if parent changed and adjust internal hierarchy info
+  void handleParentChanged(const KCalCore::Incidence::Ptr &incidence );
 
 public Q_SLOTS:
   void slotDeleteFinished( int changeId,
@@ -61,6 +65,7 @@ public Q_SLOTS:
                             const QString &errorMessage );
 
 public:
+  QMultiHash<Akonadi::Collection::Id, Akonadi::Item> mItemsByCollection;
   QHash<QString,Akonadi::Item::Id> mItemIdByUid;
   QHash<Akonadi::Item::Id, Akonadi::Item> mItemById;
   Akonadi::IncidenceChanger *mIncidenceChanger;
@@ -70,6 +75,12 @@ public:
   bool mBatchInsertionCancelled;
   bool mListensForNewItems; // does this model detect new item creations ?
 
+  // Hash with uid->parentUid. When receiving onDataChanged() we need a way
+  // to obtain the original RELATED-TO. Because RELATED-TO might have been modified
+  // we can't trust the incidence stored in the calendar. ( Users of this class don't
+  // operate on a incidence clone, they change the same incidence that's inside the calendar )
+  QHash<QString,QString> mUidToParent;
+
 private:
   CalendarBase *const q;
 };
