@@ -190,7 +190,7 @@ bool IncidenceChanger::Private::atomicOperationIsValid( uint atomicOperationId )
 {
   // Changes must be done between startAtomicOperation() and endAtomicOperation()
   return mAtomicOperations.contains( atomicOperationId ) &&
-         !mAtomicOperations[atomicOperationId]->endCalled;
+         !mAtomicOperations[atomicOperationId]->m_endCalled;
 }
 
 bool IncidenceChanger::Private::hasRights( const Collection &collection,
@@ -217,7 +217,7 @@ bool IncidenceChanger::Private::hasRights( const Collection &collection,
 Akonadi::Job* IncidenceChanger::Private::parentJob( const Change::Ptr &change ) const
 {
   return (mBatchOperationInProgress && !change->queuedModification) ?
-                                       mAtomicOperations[mLatestAtomicOperationId]->transaction : 0;
+              mAtomicOperations[mLatestAtomicOperationId]->transaction() : 0;
 }
 
 void IncidenceChanger::Private::queueModification( Change::Ptr change )
@@ -259,22 +259,22 @@ void IncidenceChanger::Private::handleTransactionJobResult( KJob *job )
   Q_ASSERT( mAtomicOperations.contains(atomicOperationId) );
   AtomicOperation *operation = mAtomicOperations[atomicOperationId];
   Q_ASSERT( operation );
-  Q_ASSERT( operation->id == atomicOperationId );
+  Q_ASSERT( operation->m_id == atomicOperationId );
   if ( job->error() ) {
     if ( !operation->rolledback() )
       operation->setRolledback();
     kError() << "Transaction failed, everything was rolledback. "
              << job->errorString();
   } else {
-    Q_ASSERT( operation->endCalled );
+    Q_ASSERT( operation->m_endCalled );
     Q_ASSERT( !operation->pendingJobs() );
   }
 
-  if ( !operation->pendingJobs() && operation->endCalled ) {
+  if ( !operation->pendingJobs() && operation->m_endCalled ) {
     delete mAtomicOperations.take( atomicOperationId );
     mBatchOperationInProgress = false;
   } else {
-    operation->transactionCompleted = true;
+    operation->m_transactionCompleted = true;
   }
 }
 
@@ -294,9 +294,9 @@ void IncidenceChanger::Private::handleCreateJobResult( KJob *job )
   QString description;
   if ( change->atomicOperationId != 0 ) {
     AtomicOperation *a = mAtomicOperations[change->atomicOperationId];
-    a->numCompletedChanges++;
+    a->m_numCompletedChanges++;
     change->completed = true;
-    description = a->description;
+    description = a->m_description;
   }
 
   if ( j->error() ) {
@@ -345,9 +345,9 @@ void IncidenceChanger::Private::handleDeleteJobResult( KJob *job )
   QString description;
   if ( change->atomicOperationId != 0 ) {
     AtomicOperation *a = mAtomicOperations[change->atomicOperationId];
-    a->numCompletedChanges++;
+    a->m_numCompletedChanges++;
     change->completed = true;
-    description = a->description;
+    description = a->m_description;
   }
   if ( j->error() ) {
     resultCode = ResultCodeJobError;
@@ -393,9 +393,9 @@ void IncidenceChanger::Private::handleModifyJobResult( KJob *job )
   QString description;
   if ( change->atomicOperationId != 0 ) {
     AtomicOperation *a = mAtomicOperations[change->atomicOperationId];
-    a->numCompletedChanges++;
+    a->m_numCompletedChanges++;
     change->completed = true;
-    description = a->description;
+    description = a->m_description;
   }
   if ( j->error() ) {
     if ( deleteAlreadyCalled( item.id() ) ) {
@@ -460,37 +460,48 @@ bool IncidenceChanger::Private::handleInvitationsBeforeChange( const Change::Ptr
         Q_ASSERT( !change->originalItems.isEmpty() );
         foreach( const Akonadi::Item &item, change->originalItems ) {
           Q_ASSERT( item.hasPayload<KCalCore::Incidence::Ptr>() );
-          Incidence::Ptr incidence = item.payload<KCalCore::Incidence::Ptr>();
-          if ( !incidence->supportsGroupwareCommunication() )
+          Incidence::Ptr incidence = CalendarUtils::incidence( item );
+          if ( !incidence->supportsGroupwareCommunication() ) {
             continue;
-          status = handler.sendIncidenceDeletedMessage( KCalCore::iTIPCancel, incidence );
-          if ( change->atomicOperationId ) {
-            mInvitationStatusByAtomicOperation.insert( change->atomicOperationId, status );
           }
-          result = status != ITIPHandlerHelper::ResultFailAbortUpdate;
-          //TODO: with some status we want to break immediately
+          // We only send CANCEL if we're the organizer.
+          // If we're not, then we send REPLY with PartStat=Declined in handleInvitationsAfterChange()
+          if ( Akonadi::CalendarUtils::thatIsMe( incidence->organizer()->email() ) ) {
+            status = handler.sendIncidenceDeletedMessage( KCalCore::iTIPCancel, incidence );
+            if ( change->atomicOperationId ) {
+              mInvitationStatusByAtomicOperation.insert( change->atomicOperationId, status );
+            }
+            result = status != ITIPHandlerHelper::ResultFailAbortUpdate;
+            //TODO: with some status we want to break immediately
+          }
         }
       }
       break;
       case IncidenceChanger::ChangeTypeModify:
       {
-        if ( !change->originalItems.isEmpty() ) {
-          Q_ASSERT( change->originalItems.count() == 1 );
-          Incidence::Ptr oldIncidence = change->originalItems.first().payload<KCalCore::Incidence::Ptr>();
-          Incidence::Ptr newIncidence = change->newItem.payload<KCalCore::Incidence::Ptr>();
-
-          if ( oldIncidence->supportsGroupwareCommunication() ) {
-            const bool modify = handler.handleIncidenceAboutToBeModified( newIncidence );
-            if ( !modify ) {
-              if ( newIncidence->type() == oldIncidence->type() ) {
-                IncidenceBase *i1 = newIncidence.data();
-                IncidenceBase *i2 = oldIncidence.data();
-                *i1 = *i2;
-              }
-              result = false;
-            }
-          }
+        if ( change->originalItems.isEmpty() ) {
+          break;
         }
+
+        Q_ASSERT( change->originalItems.count() == 1 );
+        Incidence::Ptr oldIncidence = change->originalItems.first().payload<KCalCore::Incidence::Ptr>();
+        Incidence::Ptr newIncidence = change->newItem.payload<KCalCore::Incidence::Ptr>();
+
+        if ( !oldIncidence->supportsGroupwareCommunication() ) {
+          break;
+        }
+
+        const bool modify = handler.handleIncidenceAboutToBeModified( newIncidence );
+        if ( modify ) {
+          break;
+        }
+
+        if ( newIncidence->type() == oldIncidence->type() ) {
+          IncidenceBase *i1 = newIncidence.data();
+          IncidenceBase *i2 = oldIncidence.data();
+          *i1 = *i2;
+        }
+        result = false;
       }
       break;
       default:
@@ -563,25 +574,34 @@ bool IncidenceChanger::Private::handleInvitationsAfterChange( const Change::Ptr
       break;
       case IncidenceChanger::ChangeTypeModify:
       {
-        if ( !change->originalItems.isEmpty() ) {
-          Q_ASSERT( change->originalItems.count() == 1 );
-          Incidence::Ptr oldIncidence = change->originalItems.first().payload<KCalCore::Incidence::Ptr>();
-          Incidence::Ptr newIncidence = change->newItem.payload<KCalCore::Incidence::Ptr>();
-          if ( newIncidence->supportsGroupwareCommunication() ) {
-            if ( mInvitationStatusByAtomicOperation.contains( change->atomicOperationId ) ) {
-              handler.setDefaultAction( actionFromStatus( mInvitationStatusByAtomicOperation.value( change->atomicOperationId ) ) );
-            }
-            const bool attendeeStatusChanged = myAttendeeStatusChanged( newIncidence,
-                                                                        oldIncidence,
-                                                                        Akonadi::CalendarUtils::allEmails() );
-            ITIPHandlerHelper::SendResult status = handler.sendIncidenceModifiedMessage( KCalCore::iTIPRequest,
-                                                                                              newIncidence,
-                                                                                              attendeeStatusChanged );
+        if ( change->originalItems.isEmpty() ) {
+          break;
+        }
 
-            if ( change->atomicOperationId != 0 ) {
-              mInvitationStatusByAtomicOperation.insert( change->atomicOperationId, status );
-            }
-          }
+        Q_ASSERT( change->originalItems.count() == 1 );
+        Incidence::Ptr oldIncidence = CalendarUtils::incidence( change->originalItems.first() );
+        Incidence::Ptr newIncidence = CalendarUtils::incidence( change->newItem );
+
+        if ( !newIncidence->supportsGroupwareCommunication() ||
+             !Akonadi::CalendarUtils::thatIsMe( newIncidence->organizer()->email() ) ) {
+          // If we're not the organizer, the user already saw the "Do you really want to do this, incidence will become out of sync"
+          break;
+        }
+
+        if ( mInvitationStatusByAtomicOperation.contains( change->atomicOperationId ) ) {
+          handler.setDefaultAction( actionFromStatus( mInvitationStatusByAtomicOperation.value( change->atomicOperationId ) ) );
+        }
+
+        const bool attendeeStatusChanged = myAttendeeStatusChanged( newIncidence,
+                                                                    oldIncidence,
+                                                                    Akonadi::CalendarUtils::allEmails() );
+
+        ITIPHandlerHelper::SendResult status = handler.sendIncidenceModifiedMessage( KCalCore::iTIPRequest,
+                                                                                     newIncidence,
+                                                                                     attendeeStatusChanged );
+
+        if ( change->atomicOperationId != 0 ) {
+          mInvitationStatusByAtomicOperation.insert( change->atomicOperationId, status );
         }
       }
       break;
@@ -945,7 +965,13 @@ void IncidenceChanger::Private::performModification( Change::Ptr change )
     return;
   }
 
-  handleInvitationsBeforeChange( change );
+  const bool userCancelled = !handleInvitationsBeforeChange( change );
+  if ( userCancelled ) {
+    // User got a "You're not the organizer, do you really want to send" dialog, and said "no"
+    kDebug() << "User cancelled, giving up";
+    emitModifyFinished( q, changeId, newItem, ResultCodeUserCanceled, QString() );
+    return;
+  }
 
   QHash<Akonadi::Item::Id, int> &latestRevisionByItemId =
                                                  ConflictPreventer::self()->mLatestRevisionByItemId;
@@ -1003,13 +1029,9 @@ void IncidenceChanger::startAtomicOperation( const QString &operationDescription
   ++d->mLatestAtomicOperationId;
   d->mBatchOperationInProgress = true;
 
-  AtomicOperation *atomicOperation = new AtomicOperation( d->mLatestAtomicOperationId );
-  atomicOperation->description = operationDescription;
+  AtomicOperation *atomicOperation = new AtomicOperation( d, d->mLatestAtomicOperationId );
+  atomicOperation->m_description = operationDescription;
   d->mAtomicOperations.insert( d->mLatestAtomicOperationId, atomicOperation );
-  d->mAtomicOperationByTransaction.insert( atomicOperation->transaction, d->mLatestAtomicOperationId );
-
-  d->connect( atomicOperation->transaction, SIGNAL(result(KJob*)),
-              d, SLOT(handleTransactionJobResult(KJob*)) );
 }
 
 void IncidenceChanger::endAtomicOperation()
@@ -1026,12 +1048,12 @@ void IncidenceChanger::endAtomicOperation()
   Q_ASSERT( d->mAtomicOperations.contains(d->mLatestAtomicOperationId) );
   AtomicOperation *atomicOperation = d->mAtomicOperations[d->mLatestAtomicOperationId];
   Q_ASSERT( atomicOperation );
-  atomicOperation->endCalled = true;
+  atomicOperation->m_endCalled = true;
 
   const bool allJobsCompleted = !atomicOperation->pendingJobs();
 
   if ( allJobsCompleted && atomicOperation->rolledback() &&
-       atomicOperation->transactionCompleted ) {
+       atomicOperation->m_transactionCompleted ) {
     // The transaction job already completed, we can cleanup:
     delete d->mAtomicOperations.take( d->mLatestAtomicOperationId );
     d->mBatchOperationInProgress = false;
@@ -1167,7 +1189,7 @@ void IncidenceChanger::Private::cleanupTransaction()
   AtomicOperation *operation = mAtomicOperations[mLatestAtomicOperationId];
   Q_ASSERT( operation );
   Q_ASSERT( operation->rolledback() );
-  if ( !operation->pendingJobs() && operation->endCalled && operation->transactionCompleted ) {
+  if ( !operation->pendingJobs() && operation->m_endCalled && operation->m_transactionCompleted ) {
     delete mAtomicOperations.take(mLatestAtomicOperationId);
     mBatchOperationInProgress = false;
   }
@@ -1184,11 +1206,11 @@ bool IncidenceChanger::Private::allowAtomicOperation( int atomicOperationId,
     if ( change->type == ChangeTypeCreate ) {
       allow = true;
     } else if ( change->type == ChangeTypeModify ) {
-      allow = !operation->mItemIdsInOperation.contains( change->newItem.id() );
+      allow = !operation->m_itemIdsInOperation.contains( change->newItem.id() );
     } else if ( change->type == ChangeTypeDelete ) {
       DeletionChange::Ptr deletion = change.staticCast<DeletionChange>();
       foreach( Akonadi::Item::Id id, deletion->mItemIds ) {
-        if ( operation->mItemIdsInOperation.contains( id ) ) {
+        if ( operation->m_itemIdsInOperation.contains( id ) ) {
           allow = false;
           break;
         }
@@ -1254,3 +1276,31 @@ void IncidenceChanger::cancelAttendees( const Akonadi::Item &aitem )
 }
 
 */
+
+AtomicOperation::AtomicOperation( IncidenceChanger::Private *icp,
+                                  uint ident ) : m_id ( ident )
+                                               , m_endCalled( false )
+                                               , m_numCompletedChanges( 0 )
+                                               , m_transactionCompleted( false )
+                                               , m_wasRolledback( false )
+                                               , m_transaction( 0 )
+                                               , m_incidenceChangerPrivate( icp )
+
+{
+  Q_ASSERT( m_id != 0 );
+}
+
+Akonadi::TransactionSequence *AtomicOperation::transaction()
+{
+  if ( !m_transaction ) {
+    m_transaction = new Akonadi::TransactionSequence;
+    m_transaction->setAutomaticCommittingEnabled( true );
+
+    m_incidenceChangerPrivate->mAtomicOperationByTransaction.insert( m_transaction, m_id );
+
+    QObject::connect( m_transaction, SIGNAL(result(KJob*)),
+                      m_incidenceChangerPrivate, SLOT(handleTransactionJobResult(KJob*)) );
+  }
+
+  return m_transaction;
+}
