@@ -22,7 +22,7 @@
 
 #include "collection.h"
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QtCore/QHash>
 #include <QtCore/QList>
@@ -46,7 +46,7 @@ class CollectionModelPrivate
 {
   public:
     Q_DECLARE_PUBLIC( CollectionModel )
-    CollectionModelPrivate( CollectionModel *parent )
+    explicit CollectionModelPrivate( CollectionModel *parent )
       : q_ptr( parent ), monitor( 0 ), session( 0 ), fetchStatistics( false ), unsubscribed( false ),
         headerContent( i18nc( "@title:column, name of a thing", "Name" ) )
     {
