@@ -210,7 +210,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
           "    { ?r ?p \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. "
-          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily)) . }"
+          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily, nco:nameAdditional)) . }"
           "    UNION "
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> . } "
@@ -369,7 +369,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
           "    { ?r ?p ?v . "
-          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily)). "
+          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily, nco:nameAdditional)). "
           "      ?v bif:contains \"'%1'\" . }"
           "    UNION "
           "    { ?r nco:hasEmailAddress ?email . "
@@ -534,7 +534,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "  "
           "    ?r<" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
           "    { ?r ?p ?v ."
-          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily) ) ."
+          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily, nco:nameAdditional) ) ."
           "%1 } UNION"
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress ?v . "
