@@ -22,7 +22,6 @@
 #include "displaynameeditwidget.h"
 
 #include <QtCore/QEvent>
-#include <QtCore/QString>
 #include <QAbstractItemView>
 #include <QHBoxLayout>
 #include <QPainter>
@@ -31,7 +30,7 @@
 #include <kabc/addressee.h>
 #include <kcombobox.h>
 #include <kdialog.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 // Tries to guess the display type that is used for the passed contact
 static DisplayNameEditWidget::DisplayType guessedDisplayType( const KABC::Addressee &contact )
