@@ -1572,20 +1572,9 @@ void EntityTreeModelPrivate::ref( Collection::Id id )
 bool EntityTreeModelPrivate::shouldPurge( Collection::Id id )
 {
   // reference counted collections should never be purged
-  // they first have to be deref'ed until they reach 0
-  if ( m_monitor->d_ptr->refCountMap.contains( id ) ) {
-    return false;
-  }
-
-  // if the collection is buffered, keep it
-  if ( m_monitor->d_ptr->m_buffer.isBuffered( id ) ) {
-    return false;
-  }
-
-  static const int MAXITEMS = 10000;
-
-  // if we do not exceed the maximum items limit, keep it
-  if ( m_items.size() < MAXITEMS ) {
+  // they first have to be deref'ed until they reach 0.
+  // if the collection is buffered, keep it.
+  if ( m_monitor->d_ptr->isMonitored( id ) ) {
     return false;
   }
 
@@ -1905,6 +1894,11 @@ bool EntityTreeModelPrivate::canFetchMore( const QModelIndex & parent ) const
       return false;
     }
 
+    // If the collection is no longer monitored by the monitor we have to refetch
+    if ( !m_monitor->d_ptr->isMonitored( colId ) ) {
+      return true;
+    }
+
     // Collections which contain no items at all can't contain more
     if ( m_collectionsWithoutItems.contains( colId ) ) {
       return false;
