@@ -124,7 +124,6 @@ namespace GpgME {
         FdPointerFeature                           = 0x10000000,
         G13VFSFeature                              = 0x20000000,
         PasswdFeature                              = 0x40000000, // gpgme >= 1.3.0
-        // reserved
         // unusable (max value)
 
         FeatureMaxValue                            = 0x80000000
@@ -132,7 +131,8 @@ namespace GpgME {
     enum Feature2 {
         Feature2MaxValue                           = 0x80000000
     };
-    GPGMEPP_EXPORT bool hasFeature( unsigned long feature );
+    // use hasFeature( unsigned long, unsigned long ) instead
+    GPGMEPP_EXPORT_DEPRECATED bool hasFeature( unsigned long feature );
     GPGMEPP_EXPORT bool hasFeature( unsigned long feature, unsigned long feature2 );
 
 } // namespace GpgME
