@@ -30,6 +30,8 @@
 
 namespace KABC {
 
+class PicturePrivate;
+
 /**
   A class to store a picture of an addressee. It can store the data directly or
   an url reference to a picture.
@@ -140,7 +142,7 @@ class KABC_EXPORT Picture
 
     /**
      * Sets the type of the picture.
-     *
+     * @param type the picture's data type
      * @deprecated type should only be set along with setRawData()
      */
     void KDE_DEPRECATED setType( const QString &type );
@@ -182,8 +184,7 @@ class KABC_EXPORT Picture
     QString toString() const;
 
   private:
-    class Private;
-    QSharedDataPointer<Private> d;
+    QSharedDataPointer<PicturePrivate> d;
 };
 
 /**
