@@ -139,8 +139,10 @@ void Event::setDtEnd( const KDateTime &dtEnd )
 
   d->mDtEnd = dtEnd;
   d->mMultiDayValid = false;
-  setHasEndDate( true );
-  setHasDuration( false );
+  if ( dtEnd.isValid() ) {
+    setHasEndDate( true );
+    setHasDuration( false );
+  }
   setFieldDirty( FieldDtEnd );
   updated();
 }
@@ -305,8 +307,9 @@ void Event::setDateTime( const KDateTime &dateTime, DateTimeRole role )
     case RoleDnD:
     {
       const int duration = dtStart().secsTo( dtEnd() );
+
       setDtStart( dateTime );
-      setDtEnd( dateTime.addSecs( duration ) );
+      setDtEnd( dateTime.addSecs( duration <= 0 ? 3600 : duration ) );
       break;
     }
     case RoleEnd:
