@@ -24,8 +24,48 @@
 #include <qtest_kde.h>
 QTEST_KDEMAIN( EventTest, NoGUI )
 
+Q_DECLARE_METATYPE( KCalCore::Incidence::DateTimeRole )
+
 using namespace KCalCore;
 
+void EventTest::testSetRoles_data()
+{
+  QTest::addColumn<KDateTime>( "originalDtStart" );
+  QTest::addColumn<KDateTime>( "originalDtEnd" );
+
+  QTest::addColumn<KCalCore::Incidence::DateTimeRole>( "setRole" );
+  QTest::addColumn<KDateTime>( "dateTimeToSet" );
+  QTest::addColumn<KDateTime>( "expectedDtStart" );
+  QTest::addColumn<KDateTime>( "expectedDtEnd" );
+
+
+  const KDateTime todayDate( QDate::currentDate() ); // all day event
+  const KDateTime todayDateTime = KDateTime::currentUtcDateTime();
+
+  QTest::newRow( "dnd 0 duration" ) << todayDate << todayDate << KCalCore::Incidence::RoleDnD
+                                    << todayDateTime << todayDateTime << todayDateTime.addSecs(3600);
+}
+
+void EventTest::testSetRoles()
+{
+  QFETCH( KDateTime, originalDtStart );
+  QFETCH( KDateTime, originalDtEnd );
+  QFETCH( KCalCore::Incidence::DateTimeRole, setRole );
+
+  QFETCH( KDateTime, dateTimeToSet );
+  QFETCH( KDateTime, expectedDtStart );
+  QFETCH( KDateTime, expectedDtEnd );
+
+  Event::Ptr event = Event::Ptr( new Event() );
+  event->setDtStart( originalDtStart );
+  event->setDtEnd( originalDtEnd );
+  event->setAllDay( originalDtStart.isDateOnly() );
+
+  event->setDateTime( dateTimeToSet, setRole );
+  QCOMPARE( event->dtStart(), expectedDtStart );
+  QCOMPARE( event->dtEnd(), expectedDtEnd );
+}
+
 void EventTest::testValidity()
 {
   QDate dt = QDate::currentDate();
@@ -114,3 +154,24 @@ void EventTest::testAssign()
   Event event2 = event1;
   QVERIFY( event1 == event2 );
 }
+
+void EventTest::testDurationDtEnd()
+{
+  const QDate dt = QDate::currentDate();
+
+  {
+    Event event;
+    event.setDtStart( KDateTime( dt ) );
+    event.setDtEnd( KDateTime( dt ).addDays( 1 ) );
+    QCOMPARE( event.hasEndDate(), true );
+    QCOMPARE( event.hasDuration(), false );
+  }
+  {
+    Event event;
+    event.setDtStart( KDateTime( dt ) );
+    event.setDuration( Duration( KDateTime( dt ), KDateTime( dt ).addDays( 1 ) ) );
+    QCOMPARE( event.hasDuration(), true );
+    QCOMPARE( event.hasEndDate(), false );
+  }
+
+}
