@@ -28,11 +28,14 @@ class EventTest : public QObject
 {
   Q_OBJECT
   private Q_SLOTS:
+    void testSetRoles_data();
+    void testSetRoles();
     void testValidity();
     void testCompare();
     void testClone();
     void testCopy();
     void testAssign();
+    void testDurationDtEnd();
 };
 
 #endif
